@@ -27,8 +27,7 @@ import pandas as pd
 import seaborn as sns
 from tqdm.auto import tqdm
 
-# TODO: Figure out where simulator should be getting compiled to, don't rely on setup.py in this folder
-import simulator
+from . import simulator
 
 # TODO: these names are not showing up in the mouseover information
 State = Hashable
@@ -343,7 +342,7 @@ class Simulation:
             timer: If True, and there are no other snapshot objects, a default TimeUpdate
                 Snapshot will be created to print the current parallel time.
         """
-        if len(self.snapshots) is 0 and timer is True:
+        if len(self.snapshots) == 0 and timer is True:
             self.add_snapshot(TimeUpdate())
 
         # stop_condition() returns True when it is time to stop
